/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.validator;

public class Procedure {

    /**
     * <p>Current Procedural Terminology Code</p>
     */
    private String cpt = null;

    /**
     * <p>Description of the CPT code.</p>
     */
    private String descr = null;

    /**
     * <p>Minimum allowable amount for the procedure.</p>
     */
    private double minAmt = 0;

    /**
     * <p>Maximum allowable amount for the procedure.</p>
     */
    private double maxAmt = 0;

    /**
     * <p>Billed amount for the procedure.</p>
     */
    private double billedAmt = 0;

    /**
     * @param cpt procedure code
     * @param descr procedure description
     * @param minAmt minimum allowable amount
     * @param maxAmt maximum allowable amount
     */
    public Procedure(String cpt, String descr, double minAmt, double maxAmt) {
        this.cpt = cpt;
        this.descr = descr;
        this.minAmt = minAmt;
        this.maxAmt = maxAmt;
    }
    
    private int priority;
    
    public void setPriority(int newValue) {
        priority = newValue;
    }
    
    public int getPriority() {
        return priority;
    }
    
    /**
     * @return procedure code
     */
    public String getCpt() {
        return cpt;
    }

    /**
     * @param cpt procedure code
     */
    public void setCpt(String cpt) {
        this.cpt = cpt;
    }

    /**
     * @return procedure description
     */
    public String getDescr() {
        return descr;
    }

    /**
     * @param descr procedure description
     */
    public void setDescr(String descr) {
        this.descr = descr;
    }

    /**
     * @return Maximum allowable amount for the procedure
     */
    public double getMaxAmt() {
        return maxAmt;
    }

    /**
     * @param maxAmt Maximum allowable amount for the procedure
     */
    public void setMaxAmt(double maxAmt) {
        this.maxAmt = maxAmt;
    }

    /**
     * @return Minimum allowable amount for the procedure
     */
    public double getMinAmt() {
        return minAmt;
    }

    /**
     * @param minAmt minimum allowable amount for the procedure
     */
    public void setMinAmt(double minAmt) {
        this.minAmt = minAmt;
    }

    /**
     * @return actual billed amount
     */
    public double getBilledAmt() {
        return billedAmt;
    }

    /**
     * @param billedAmt actual billed amount
     */
    public void setBilledAmt(double billedAmt) {
        this.billedAmt = billedAmt;
    }

}
