/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.view;

import java.util.Map;
import org.apache.shale.view.AbstractViewController;

/**
 * <p>Test implementation of <code>Viewcontroller</code> for use by
 * <code>ViewControllerTestCase</code>.  Event history is accumulated
 * under a request scope attribute named by symbolic constant
 * <code>ATTRIBUTES</code>.</p>
 */
public class TestViewController extends AbstractViewController {
    
    /** Creates a new instance of TestViewController */
    public TestViewController() {
    }
    
    // The request scope attribute under which we accumulate events
    public static final String ATTRIBUTE =
            "org.apache.shale.usecases.systest.TestViewController.EVENTS";


    // ------------------------------------------------------- Public Properties


    /**
     * <p>Return the accumuated history string.</p>
     */
    public String getText() {
        String history = (String) getExternalContext().getRequestMap().get(ATTRIBUTE);
        if (history == null) {
            history = "";
        }
        return history;
    }


    // ---------------------------------------------------------- Event Handlers


    /**
     * <p>Do-nothing submit method.</p>
     */
    public String submit() {
        event("submit");
        return null;
    }


    // ------------------------------------------------------- Lifecycle Methods


    public void init() {
        event("init");
    }


    public void preprocess() {
        event("preprocess");
    }


    public void prerender() {
        event("prerender");
    }


    public void destroy() {
        event("destroy");
    }


    // --------------------------------------------------------- Support Methods


    private Map map = null;


    /**
     * <p>Record the specified event, a slash, the state of the postback flag,
     * and another slash.</p>
     */
    private void event(String event) {
        System.out.println("TestViewController.event(" + event + "," + isPostBack() + ")");
        if ("init".equals(event) || "destroy".equals(event)) {
            try {
                throw new IllegalArgumentException("Trace source of event '" + event + "'");
            } catch (IllegalArgumentException e) {
                e.printStackTrace();
            }
        }
        if (map == null) {
            map = getExternalContext().getRequestMap();
        }
        String history = (String) map.get(ATTRIBUTE);
        if (history == null) {
            history = "";
        }
        map.put(ATTRIBUTE, history + event + "/" + isPostBack() + "/");
    }



}
