/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.locale;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.shale.test.base.AbstractViewControllerTestCase;

/**
 * <p>Test case for the {@link Select} ViewController implementation.</p>
 *
 * $Id: SelectTestCase.java 464373 2006-10-16 04:21:54Z rahul $
 */
public class SelectTestCase extends AbstractViewControllerTestCase {


    // ------------------------------------------------------------ Constructors


    // Construct a new instance of this test case.
    public SelectTestCase(String name) {
        super(name);
    }


    // ---------------------------------------------------- Overall Test Methods


    // Set up instance variables required by this test case.
    protected void setUp() throws Exception {

        super.setUp();

        // Configure the supported locales for this application
        List list = new ArrayList();
        list.add(new Locale("en"));
        list.add(new Locale("fr"));
        list.add(new Locale("de"));
        list.add(new Locale("es"));
        application.setSupportedLocales(list);

        // Construct a new ViewController instance
        vc = new Select();

    }

    // Return the tests included in this test case.
    public static Test suite() {

        return (new TestSuite(SelectTestCase.class));

    }


    // Tear down instance variables required by this test case.
    protected void tearDown() throws Exception {

        vc = null;
        super.tearDown();

    }


    // ------------------------------------------------------ Instance Variables


    // The instance to be tested
    Select vc = null;


    // ------------------------------------------------------------ Test Methods


    // Test behavior of prerender() method
    public void testPrerender() {

        Locale locale = new Locale("en");
        facesContext.getViewRoot().setLocale(locale);
        vc.init();
        vc.prerender();
        assertEquals(locale.toString(), vc.getLocale());

    }


    // Test a pristine instance of {@link Select}
    public void testPristine() {

        assertNull(vc.getLocale());

    }


    // Test behavior of select() with an invalid value
    public void testSelectInvalid() {

        Locale locale = new Locale("en");
        facesContext.getViewRoot().setLocale(locale);
        vc.init();
        vc.preprocess();
        vc.setLocale("it");
        String result = vc.select();
        assertEquals(Select.FAILURE, result);
        checkMessageCount(1);
        assertEquals(locale, facesContext.getViewRoot().getLocale());

    }


    // Test behavior of select() with no input value at all
    public void testSelectNull() {

        Locale locale = new Locale("en");
        facesContext.getViewRoot().setLocale(locale);
        vc.init();
        vc.preprocess();
        vc.setLocale(null);
        String result = vc.select();
        assertNull(result);
        checkMessageCount(1);
        assertEquals(locale, facesContext.getViewRoot().getLocale());

    }


    // Test behavior of select() with a valid value
    public void testSelectValid() {

        Locale locale = new Locale("en");
        facesContext.getViewRoot().setLocale(locale);
        vc.init();
        vc.preprocess();
        vc.setLocale("de");
        String result = vc.select();
        assertEquals(result, Select.SUCCESS);
        checkMessageCount(0);
        assertEquals(new Locale("de"), facesContext.getViewRoot().getLocale());

    }


}
