/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.systest;

import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
import com.gargoylesoftware.htmlunit.html.HtmlForm;
import com.gargoylesoftware.htmlunit.html.HtmlSpan;
import com.gargoylesoftware.htmlunit.html.HtmlSubmitInput;
import junit.framework.Test;
import junit.framework.TestSuite;
import org.apache.shale.test.cargo.CargoTestSetup;

/**
 * <p>Validate the "JNDI access" path through the application</p>
 */
public class JndiTestCase extends AbstractTestCase {
    

    // ------------------------------------------------------------ Constructors


    /**
     * <p>Construct a new instance of this test case.</p>
     *
     * @param name Name of the new test case
     */
    public JndiTestCase(String name) {

        super(name);

    }


    // ------------------------------------------------------ Instance Variables


    // ------------------------------------------------------ Test Setup Methods


    /**
     * <p>Set up the instance variables required for this test case.</p>
     */
    protected void setUp() throws Exception {

        super.setUp();
        page("/jndi/test.faces");

    }


    /**
     * <p>Return the set of tests included in this test suite.</p>
     */
    public static Test suite() {

        return new CargoTestSetup(new TestSuite(JndiTestCase.class));

    }


    /**
     * <p>Tear down instance variables required by this test case.</p>
     */
    protected void tearDown() throws Exception {

        super.tearDown();

    }



    // ------------------------------------------------- Individual Test Methods


    /**
     * <p>Execute the "Jndi Access" path.</p>
     */
    public void testExecute() throws Exception {

        HtmlSpan span, expected, actual = null;
        HtmlSubmitInput submit = null;

        // setUp() should have put us on the page
        assertEquals("JNDI Test Title", title());

        // Verify contents of the page
        expected = (HtmlSpan) element("form:expected");
        assertNotNull(expected);
        actual = (HtmlSpan) element("form:actual");
        assertNotNull(actual);
        assertEquals(expected.asText(), actual.asText());

        // Advance to the menu
        submit = (HtmlSubmitInput) element("form:finish");
        assertNotNull(submit);
        submit(submit);
        assertEquals("Shale Framework Use Cases", title());

    }


}
